bug-findutils
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Typo fixes for findutils-4.2.18


From: Martin Buchholz
Subject: Typo fixes for findutils-4.2.18
Date: Sun, 20 Feb 2005 16:05:04 -0800

All trivial fixes.


diff -u '/usr/tmp/mp20635.d/old/findutils-4.2.18/doc/find.texi' 
'findutils-4.2.18/doc/find.texi'
Index: ./doc/find.texi
--- ./doc/find.texi     Sun Feb 13 04:11:54 2005
+++ ./doc/find.texi     Sun Feb 20 15:49:54 2005
@@ -3083,7 +3083,7 @@
 * O_FOLLOW::                       Safely changing directory using fchdir().
 * Systems without O_NOFOLLOW::     Checking for symbolic links after chdir().
 * Working with automounters::      These can look like race condition exploits
-* Problems with dead NFS servers:: If you don't have O_FOLLOW, this ia a 
problem.
+* Problems with dead NFS servers:: If you don't have O_FOLLOW, this is a 
problem.
 @end menu
 
 @node O_FOLLOW
@@ -3137,8 +3137,8 @@
 error message is issued and @code{find} exits immediately.  This
 method also prevents filesystem manipulation attacks from persuading
 @code{find} to search parts of the filesystem it did not intend.
-However, we heve to take special steps in order not to be
-unneccessarily concluding that there is a problem aut ``automount''
+However, we have to take special steps in order not to be
+unnecessarily concluding that there is a problem with ``automount''
 mount points.
 
 @node Working with automounters
diff -u '/usr/tmp/mp20635.d/old/findutils-4.2.18/find/defs.h' 
'findutils-4.2.18/find/defs.h'
Index: ./find/defs.h
--- ./find/defs.h       Sat Feb 12 02:36:03 2005
+++ ./find/defs.h       Sun Feb 20 15:49:21 2005
@@ -318,7 +318,7 @@
   } args;
 
   /* The next predicate in the user input sequence,
-     which repesents the order in which the user supplied the
+     which represents the order in which the user supplied the
      predicates on the command line. */
   struct predicate *pred_next;
 
diff -u '/usr/tmp/mp20635.d/old/findutils-4.2.18/find/find.c' 
'findutils-4.2.18/find/find.c'
Index: ./find/find.c
--- ./find/find.c       Wed Feb 16 01:51:08 2005
+++ ./find/find.c       Sun Feb 20 15:50:56 2005
@@ -199,7 +199,7 @@
     }
   else
     {
-      /* Not a file on the command line; do not derefernce the link.
+      /* Not a file on the command line; do not dereference the link.
        */
       return lstat(name, p);
     }
@@ -273,7 +273,7 @@
 
   options.symlink_handling = opt;
   
-  /* For DBEUG_STAT, the choice is made at runtime within debug_stat()
+  /* For DEBUG_STAT, the choice is made at runtime within debug_stat()
    * by checking the contents of the symlink_handling variable.
    */
 #if defined(DEBUG_STAT)
@@ -909,7 +909,7 @@
   };
 
 /* Safely perform a change in directory.  We do this by calling
- * lstat() on the subdirectory, using chdir() tro move into it, and
+ * lstat() on the subdirectory, using chdir() to move into it, and
  * then lstat()ing ".".  We compare the results of the two stat calls
  * to see if they are consistent.  If not, we sound the alarm.
  *
@@ -1060,7 +1060,7 @@
    */
   saved_errno = 0;
   
-  /* We use the same exit path for successs or failure. 
+  /* We use the same exit path for success or failure. 
    * which has occurred is recorded in RV. 
    */
  fail:
@@ -1204,7 +1204,7 @@
    Actions like -execdir assume that we are in the 
    parent directory of the file we're examining, 
    and on entry to this function our working directory
-   is whetever it was when find was invoked.  Therefore
+   is whatever it was when find was invoked.  Therefore
    If PATHNAME is "." we just leave things as they are. 
    Otherwise, we figure out what the parent directory is, 
    and move to that.
@@ -1436,7 +1436,7 @@
   /* From here on, we're working on a directory.  */
 
   
-  /* Now we really need to stat the directory, even if we knoe the
+  /* Now we really need to stat the directory, even if we know the
    * type, because we need information like struct stat.st_rdev.
    */
   if (get_statinfo(pathname, name, &stat_buf) != 0)
@@ -1525,7 +1525,7 @@
          struct exec_val *execp = &p->args.exec_vec;
          
          /* This one was terminated by '+' and so might have some
-          * left... Run it if neccessary.  
+          * left... Run it if necessary.
           */
          if (execp->state.todo)
            {
@@ -1564,7 +1564,7 @@
       struct exec_val *execp = &p->args.exec_vec;
       
       /* This one was terminated by '+' and so might have some
-       * left... Run it if neccessary.  Set state.exit_status if
+       * left... Run it if necessary.  Set state.exit_status if
        * there are any problems.
        */
       if (execp->state.todo)
diff -u '/usr/tmp/mp20635.d/old/findutils-4.2.18/find/parser.c' 
'findutils-4.2.18/find/parser.c'
Index: ./find/parser.c
--- ./find/parser.c     Sat Feb 12 12:49:25 2005
+++ ./find/parser.c     Sun Feb 20 15:48:56 2005
@@ -312,7 +312,7 @@
                  if ((first_nonoption_arg != NULL)
                      && options.warnings )
                    {
-                     /* option which folows a non-option */
+                     /* option which follows a non-option */
                      error (0, 0,
                             _("warning: you have specified the %s "
                               "option after a non-option argument %s, "
@@ -2259,8 +2259,8 @@
   return (true);
 }
 
-/* Get a number with comparision information.
-   The sense of the comparision information is 'normal'; that is,
+/* Get a number with comparison information.
+   The sense of the comparison information is 'normal'; that is,
    '+' looks for a count > than the number and '-' less than.
    
    STR is the ASCII representation of the number.




reply via email to

[Prev in Thread] Current Thread [Next in Thread]